window.onload = function () {
    var spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"), { sheetCount: 1 });
    initSpread(spread);
};

// Create the data source and set it as a table in the sheet
function getDataSource(sheet) {
    sheet.name("DataSource");
    var table = sheet.tables.add('PivotBudget', 0, 0, sheet.getRowCount(), sheet.getColumnCount());
    table.style(GC.Spread.Sheets.Tables.TableThemes["none"]);
    return table.name();
}

// Create the pivot table based on the data table
function initPivotTable(sheet, tableName) {
    sheet.name("Budgeting PivotTable");
    sheet.setRowCount(1000);
    var pivotTableOptions = {bandRows:true, bandColumns:true, grandTotalPosition: GC.Spread.Pivot.GrandTotalPosition.none};
    var pivotTable = sheet.pivotTables.add("PivotTable", tableName, 1, 1, GC.Spread.Pivot.PivotTableLayoutType.outline, GC.Spread.Pivot.PivotTableThemes.medium10, pivotTableOptions);
    pivotTable.suspendLayout();

    pivotTable.add("Country", "Country", GC.Spread.Pivot.PivotTableFieldType.filterField);
    
    pivotTable.add("Division", "Division", GC.Spread.Pivot.PivotTableFieldType.rowField);
    pivotTable.add("Item","Item", GC.Spread.Pivot.PivotTableFieldType.rowField);
    pivotTable.add("Year", "Year", GC.Spread.Pivot.PivotTableFieldType.columnField);
    pivotTable.add("Budget", "Budget$", GC.Spread.Pivot.PivotTableFieldType.valueField);
    pivotTable.add("Actual", "Actual$", GC.Spread.Pivot.PivotTableFieldType.valueField);
    pivotTable.add("Variance", "Variance$", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.var);
    pivotTable.dataPosition(GC.Pivot.DataPosition, 1);

    var panel = new GC.Spread.Pivot.PivotPanel("PivotPanel", pivotTable, document.getElementById("panel"));
    panel.sectionVisibility(GC.Spread.Pivot.PivotPanelSection.fields + GC.Spread.Pivot.PivotPanelSection.area);
    
    var style = new GC.Spread.Sheets.Style();
    style.formatter = "$ #,##0";
    pivotTable.setStyle({dataOnly: true}, style);

    pivotTable.resumeLayout();
    pivotTable.autoFitColumn();
}

// Initialize the SpreadJS instance
function initSpread(spread, data) {
    spread.suspendPaint();

    spread.fromJSON(Budget);
    spread.addSheet(spread.getSheetCount());
    var dataSheet = spread.getSheet(0);
    var pivotSheet = spread.getSheet(1);

    var tableName = getDataSource(dataSheet);
    initPivotTable(pivotSheet, tableName);

    spread.setActiveSheetIndex(1);
    spread.resumePaint();
}
