window.onload = function () {
    var spread = new GC.Spread.Sheets.Workbook(document.getElementById("ss"), { sheetCount: 1 });
    initSpread(spread);
};

// Create the data source and set it as a table in the sheet
function getDataSource(sheet) {
    sheet.name("DataSource");
    var table = sheet.tables.add('PivotMarketing', 0, 0, sheet.getRowCount(), sheet.getColumnCount());
    table.style(GC.Spread.Sheets.Tables.TableThemes["none"]);
    return table.name();
}

// Create the pivot table based on the data table
function initPivotTable(sheet, tableName) {
    sheet.name("Marketing PivotTable");
    sheet.setRowCount(1000);
    sheet.options.gridline.showVerticalGridline = false;
    var pivotTableOptions = {grandTotalPosition:GC.Spread.Pivot.GrandTotalPosition.none, subtotalsPosition:GC.Spread.Pivot.SubtotalsPosition.top};
    var pivotTable = sheet.pivotTables.add("PivotTable", tableName, 1, 1, GC.Spread.Pivot.PivotTableLayoutType.outline, GC.Spread.Pivot.PivotTableThemes.medium3, pivotTableOptions);
    
    pivotTable.suspendLayout();

    pivotTable.add("Country/Territory (Geographic)", "Country", GC.Spread.Pivot.PivotTableFieldType.rowField);
    pivotTable.add("Impressions", "Total Impressions", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    pivotTable.add("Clicks", "Total Clicks", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    pivotTable.add("CTR", "Avg. CTR", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.average);
    pivotTable.add("Conv. rate", "Avg. Conv.", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.average);
    pivotTable.add("Cost per Lead", "Avg. CPL", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.average);
    pivotTable.add("Cost", "Total Cost", GC.Spread.Pivot.PivotTableFieldType.valueField, GC.Pivot.SubtotalType.sum);
    
    pivotTable.valueFilter("Country", {
        condition: {
            type: GC.Pivot.PivotTop10FilterType.count,
            conType: GC.Pivot.PivotConditionType.top10,
            val: 25,
            operator: GC.Pivot.PivotTop10FilterOperator.top
        },
        conditionByName: "Total Impressions"
    });

    var panel = new GC.Spread.Pivot.PivotPanel("PivotPanel", pivotTable, document.getElementById("panel"));
    panel.sectionVisibility(GC.Spread.Pivot.PivotPanelSection.fields + GC.Spread.Pivot.PivotPanelSection.area);

    var percentPivotArea = {
        dataOnly: true,
        references: [{
            fieldName: "Values",
            items: ["Avg. CTR", "Avg. Conv."]
        }]
    };
    var percentStyle = new GC.Spread.Sheets.Style();
    percentStyle.formatter = "##%";
    pivotTable.setStyle(percentPivotArea, percentStyle);

    var currencyPivotArea = {
        dataOnly: true,
        references: [{
            fieldName: "Values",
            items: ["Avg. CPL", "Total Cost"]
        }]
    }

    var dataBarRule = new GC.Spread.Sheets.ConditionalFormatting.DataBarRule();
    dataBarRule.minType(GC.Spread.Sheets.ConditionalFormatting.ScaleValueType.number);
    dataBarRule.minValue(0);
    dataBarRule.maxType(GC.Spread.Sheets.ConditionalFormatting.ScaleValueType.number);
    dataBarRule.maxValue(1);
    dataBarRule.gradient(true);
    dataBarRule.color("blue");
    dataBarRule.showBorder(true);
    dataBarRule.borderColor("white");
    dataBarRule.dataBarDirection(GC.Spread.Sheets.ConditionalFormatting.BarDirection.leftToRight);
    dataBarRule.negativeFillColor("red");
    dataBarRule.useNegativeFillColor(true);
    dataBarRule.negativeBorderColor("white");
    dataBarRule.useNegativeBorderColor(true);
    dataBarRule.axisPosition(GC.Spread.Sheets.ConditionalFormatting.DataBarAxisPosition.automatic);
    dataBarRule.axisColor("blue");
    dataBarRule.showBarOnly(false);
    pivotTable.addConditionalRule([currencyPivotArea], dataBarRule);
    
    var currencyStyle = new GC.Spread.Sheets.Style();
    currencyStyle.formatter = "$ #,##0.##";
    pivotTable.setStyle(currencyPivotArea, currencyStyle);

    pivotTable.resumeLayout();
    pivotTable.autoFitColumn();
    
}

// Initialize the SpreadJS instance
function initSpread(spread) {
    spread.suspendPaint();

    spread.fromJSON(Marketing);
    spread.addSheet(spread.getSheetCount());
    var dataSheet = spread.getSheet(0);
    var pivotSheet = spread.getSheet(1);

    var tableName = getDataSource(dataSheet);
    initPivotTable(pivotSheet, tableName);

    spread.setActiveSheetIndex(1);
    spread.resumePaint();
}
